@@ -241,6 +241,10 @@ def _processKeyboardEvent(event):
     # Special modes.
     if not isPressedEvent and keyboardEvent.event_string == "Escape":
         script.exitLearnMode(keyboardEvent)
+    if orca_state.learnModeEnabled and keyboardEvent.event_string == "F1" \
+       and not keyboardEvent.modifiers:
+        orca_state.learnModeEnabled = False
+        return helpForOrca()
     if orca_state.capturingKeys:
         return False
     if orca_state.listShortcutsModeEnabled:
@@ -468,8 +472,6 @@ def loadUserSettings(script=None, inputEvent=None, skipReloadMessage=False):
     _storeXmodmap(_orcaModifiers)
     _createOrcaXmodmap()
 
-    showMainWindowGUI()
-
     _scriptManager.activate()
     _eventManager.activate()
 
@@ -508,23 +510,6 @@ def showPreferencesGUI(script=None, inputEvent=None):
 
     return True
 
-def showMainWindowGUI(script=None, inputEvent=None):
-    """Displays the Orca main window.
-
-    Returns True to indicate the input event has been consumed.
-    """
-
-    try:
-        module = importlib.import_module('.orca_gui_main', 'orca')
-        if settings.showMainWindow or settings.overrideDisabledMainWindow:
-            module.showMainUI()
-        else:
-            module.hideMainUI()
-    except:
-        debug.printException(debug.LEVEL_SEVERE)
-
-    return True
-
 def helpForOrca(script=None, inputEvent=None, page=""):
     """Show Orca Help window (part of the GNOME Access Guide).
 
@@ -713,14 +698,7 @@ def quitOrca(script=None, inputEvent=None):
     Returns True to indicate the input event has been consumed.
     """
 
-    if _settingsManager.getSetting("quitOrcaNoConfirmation"):
-        shutdown()
-    else:
-        try:
-            module = importlib.import_module('.orca_gui_quit', 'orca')
-            module.showQuitUI()
-        except:
-            debug.printException(debug.LEVEL_SEVERE)
+    shutdown()
 
     return True
 
@@ -736,24 +714,6 @@ def showFindGUI(script=None, inputEvent=None):
     except:
         debug.printException(debug.LEVEL_SEVERE)
 
-def showSplashGUI(script=None, inputEvent=None):
-    """Displays a splash screen.
-
-    Returns True to indicate the input event has been consumed.
-    """
-
-    try:
-        module = importlib.import_module('.orca_gui_splash', 'orca')
-        if _settingsManager.getSetting("showSplashWindow"):
-            module.showSplashUI()
-        else:
-            module.hideSplashUI()
-
-    except:
-        debug.printException(debug.LEVEL_SEVERE)
-
-    return True
-
 # If True, this module has been initialized.
 #
 _initialized = False
@@ -997,7 +957,6 @@ def main():
     except:
         debug.printException(debug.LEVEL_SEVERE)
 
-    showSplashGUI()
     script = orca_state.activeScript
     if script:
         window = script.utilities.activeWindow()
