@@ -376,7 +376,7 @@ class Script(default.Script):
         """
 
         boundary = pyatspi.TEXT_BOUNDARY_CHAR
-        objects = self.utilities.getObjectsFromEOCs(obj, boundary)
+        objects = self.utilities.getObjectsFromEOCs(obj, boundary=boundary)
         for (obj, start, end, string) in objects:
             if string:
                 speech.speakCharacter(string)
@@ -391,7 +391,7 @@ class Script(default.Script):
         """
 
         boundary = pyatspi.TEXT_BOUNDARY_WORD_START
-        objects = self.utilities.getObjectsFromEOCs(obj, boundary)
+        objects = self.utilities.getObjectsFromEOCs(obj, boundary=boundary)
         for (obj, start, end, string) in objects:
             self.sayPhrase(obj, start, end)
 
@@ -403,7 +403,7 @@ class Script(default.Script):
         """
 
         boundary = pyatspi.TEXT_BOUNDARY_LINE_START
-        objects = self.utilities.getObjectsFromEOCs(obj, boundary)
+        objects = self.utilities.getObjectsFromEOCs(obj, boundary=boundary)
         for (obj, start, end, string) in objects:
             self.sayPhrase(obj, start, end)
 
@@ -537,6 +537,13 @@ class Script(default.Script):
         orca.setLocusOfFocus(None, obj, notifyScript=False)
         self.updateBraille(obj)
 
+        # Hack: When panning to the left in a document, we want to start at
+        # the right/bottom of each new object. For now, we'll pan there.
+        # When time permits, we'll give our braille code some smarts.
+        while self.panBrailleInDirection(panToLeft=False):
+            pass
+        self.refreshBraille(False)
+
         return True
 
     def panBrailleRight(self, inputEvent=None, panAmount=0):
@@ -553,6 +560,13 @@ class Script(default.Script):
         orca.setLocusOfFocus(None, obj, notifyScript=False)
         self.updateBraille(obj)
 
+        # Hack: When panning to the right in a document, we want to start at
+        # the left/top of each new object. For now, we'll pan there. When time
+        # permits, we'll give our braille code some smarts.
+        while self.panBrailleInDirection(panToLeft=True):
+            pass
+        self.refreshBraille(False)
+
         return True
 
     def sayAll(self, inputEvent):
@@ -676,13 +690,53 @@ class Script(default.Script):
         where the caret is.
         """
 
-        # TODO - JD: Piece together the full line for braille
-
         textLine = default.Script.getTextLineAtCaret(self, obj, offset)
         string = textLine[0]
-        if string.find(self.EMBEDDED_OBJECT_CHARACTER) == -1:
+        if string and string.find(self.EMBEDDED_OBJECT_CHARACTER) == -1 \
+           and obj.getState().contains(pyatspi.STATE_FOCUSED):
             return textLine
 
         textLine[0] = self.utilities.displayedText(obj)
+        try:
+            text = obj.queryText()
+        except:
+            pass
+        else:
+            textLine[1] = min(textLine[1], text.characterCount)
 
         return textLine
+
+    def updateBraille(self, obj, extraRegion=None):
+        """Updates the braille display to show the given object.
+
+        Arguments:
+        - obj: the Accessible
+        - extra: extra Region to add to the end
+        """
+
+        if not obj:
+            return
+
+        if not self.utilities.isWebKitGtk(obj) \
+           or (not self.utilities.isInlineContainer(obj) \
+               and not self.utilities.isTextListItem(obj)):
+            default.Script.updateBraille(self, obj, extraRegion)
+            return
+
+        brailleLine = self.getNewBrailleLine(clearBraille=True, addLine=True)
+        for child in obj:
+            if not self.utilities.onSameLine(child, obj[0]):
+                break
+            [regions, fRegion] = self.brailleGenerator.generateBraille(child)
+            self.addBrailleRegionsToLine(regions, brailleLine)
+
+        if not brailleLine.regions:
+            [regions, fRegion] = self.brailleGenerator.generateBraille(
+                obj, role=pyatspi.ROLE_PARAGRAPH)
+            self.addBrailleRegionsToLine(regions, brailleLine)
+            self.setBrailleFocus(fRegion)
+
+        if extraRegion:
+            self.addBrailleRegionToLine(extraRegion, brailleLine)
+
+        self.refreshBraille()
